@@ -36,6 +36,7 @@
 #include "debugger_hd64180.h"
 #include "debugger_m680x0.h"
 #include "debugger_m88xx0.h"
+#include "event.h"
 #include "hostcom.h"
 #include "mainapp.h"
 #include "memdump.h"
@@ -465,7 +466,7 @@ Debugger::Input(int c)
 			 case CmdAct::Quit:
 				// アプリケーション自体を終了
 				LeavePrompt(false);
-				UIMessage::Post(UIMessage::APPEXIT);
+				gMainApp.GetUIMessage()->Post(UIMessage::APPEXIT);
 			}
 		} else if (c < ' ' || c == 0x07f) {
 			// 他のコントロールコードはとりあえず無視
