@@ -441,7 +441,7 @@ MemdumpMonitor::MemdumpMonitor(uint objid_, int monid_)
 {
 	monitor = gMonitorManager->Regist(monid_, this);
 	monitor->func = ToMonitorCallback(&MemdumpMonitor::MonitorUpdate);
-	monitor->SetSize(84, 16);
+	monitor->SetSize(84, 32);
 }
 
 // デストラクタ
@@ -758,7 +758,7 @@ MemdumpMonitor::GetPageOffset(int n) const
 	// 逆アセンブルでは実際にこの動作をすると連続性が失われて読みにくいので
 	// 1行だぶらせることにする。
 
-	int row = monitor->GetSize().height;
+	int row = monitor->GetRow();
 	if (inst_bytes) {
 		// 逆アセンブルの場合
 		if (n < 0) {
