@@ -18,80 +18,111 @@
 <div class="main1">
 <dl>
 
+<dt>1.5.0 (2025/09/07)
+<dd><ul>
+<li>vm(New): X68030 のグラフィック画面を 1024x1024 モードのみ簡易実装。
+NetBSD/x68k の X サーバが標準設定で動きます。
+ <q>Implement 1024x1024 mode of the graphic screen partially on X68030.
+ This makes NetBSD/x68k X server work though default configuration only.</q>
+<li>vm(New): VirtIO Block に VIRTIO_BLK_T_GET_ID コマンドを実装。
+ <q>Implement VIRTIO_BLK_T_GET_ID command in VirtIO Block.</q>
+<li>vm(Update): キー押下で高速モードを抑制するのを LUNA に限定する。
+ <q>Limit suppressing full speed mode by key press to LUNA.</q>
+<li>vm(Update): X68030 で SRAM.DAT がなければ初期状態で作成する。
+それに伴い --create-sram オプションを廃止。
+ <q>Create an initialized SRAM.DAT if it doesn't exist on X68030.
+ This also obsoletes --create-sram option.</q>
+<li>vm(Fix): Nereid バンクメモリのアクセスウェイトを修正。
+ <q>Fix wait state count for Nereid bank memory.</q>
+<li>m88k(Update): SFD1 がセットされていると浮動小数点命令が例外を
+起こすのを実装。
+ <q>Implement that floating-point instructions raise an exception
+ when SFD1 is set.</q>
+<li>m88k(Fix): rte 命令がユーザモードで例外を起こさなかったのを修正。
+ <q>Fix missing exception for rte instruction in user mode.</q>
+<li>GUI(Update): パフォーマンスカウンタに MHz 表記の追加。
+ <q>Display MHz too in the performance counter.</q>
+<li>GUI(Fix): いくつかのモニタウィンドウのオープン/クローズで不正終了する可能性があったのを修正。
+ <q>Fix possible abnormal termination when opening or closeing some
+ monitor windows.</q>
+<li>host(Update): ログ機構を書き直し。
+ <q>Reimplement log.</q>
+</ul><p>
+
 <dt>1.4.2 (2025/05/17)
 <dd><ul>
-<li>m88k: FP precise 例外時にソースレジスタが 0 の場合の FPHS[12]
- レジスタを修正。
- <q>Fix the FPHS[12] registers if any source register contains 0
- when the FP precise exception occurs.</q>
-<li>m88k: テーブルサーチは暗黙で CI 扱いになるところを実装。
+<li>m88k(Update): テーブルサーチは暗黙で CI 扱いになるところを実装。
  <q>Implement a table search operation with CI.</q>
-<li>m88k: CI アクセスでキャッシュヒットするとエントリが無効化されるところを実装。
+<li>m88k(Update): CI アクセスでキャッシュヒットするとエントリが無効化されるところを実装。
 この2点で、ver 0.7.1 以降 OpenBSD がまれに panic していたのが直ると思います。
  <q>Implement that a cache hit invalidates the cache entry if the accesss is CI.
  These two changes should fix an occasional OpenBSD panic since ver 0.7.1.</q>
-<li>m88k: CI 領域に対する xmem 命令の動作を修正。
+<li>m88k(Fix): CI 領域に対する xmem 命令の動作を修正。
  <q>Fix the behavior of the xmem instruction in a cache-inhibited region.</q>
-<li>m88k: バススヌープでキャッシュの状態が変わらない場合があったのを修正。
+<li>m88k(Fix): バススヌープでキャッシュの状態が変わらない場合があったのを修正。
  <q>Fix an issue that bus snooping didn't change cache status in some
  case.</q>
-<li>m88k: m88200 の Cache Copyback {,and Invalidate} コマンド実行後の
+<li>m88k(Fix): m88200 の Cache Copyback {,and Invalidate} コマンド実行後の
 キャッシュステータスを修正。
  <q>Fix the cache status on 88200 Cache Copyback {,and Invalidate} commands.</q>
+<li>m88k(Fix): FP precise 例外時にソースレジスタが 0 の場合の FPHS[12]
+ レジスタを修正。
+ <q>Fix the FPHS[12] registers if any source register contains 0
+ when the FP precise exception occurs.</q>
 </ul><p>
 
 <dt>1.4.1 (2025/04/30)
 <dd><ul>
-<li>m88k: 例外優先度をいろいろ修正。
- <q>Fix several exception priorities.</q>
-<li>m88k: 不当命令例外を実装。
+<li>m88k(New): 不当命令例外を実装。
  <q>Implement the illegal instruction exception.</q>
-<li>m88k: データアクセス例外発生時の DMx レジスタをいくつか修正。
+<li>m88k(Fix): 例外優先度をいろいろ修正。
+ <q>Fix several exception priorities.</q>
+<li>m88k(Fix): データアクセス例外発生時の DMx レジスタをいくつか修正。
  <q>Fix several DMx registers upon a data access exception.</q>
-<li>m88k: ld.d 命令の第2ワードで例外が発生した時の動作を修正。
+<li>m88k(Fix): ld.d 命令の第2ワードで例外が発生した時の動作を修正。
  <q>Fix the behavior of the ld.d instruction when an exception occurred on
  the second word.</q>
-<li>m88k: PID, SXIP レジスタが書き込み可能になっていたのを修正。
+<li>m88k(Fix): PID, SXIP レジスタが書き込み可能になっていたのを修正。
  <q>Fix that PID and SXIP registers were writeable.</q>
-<li>m88k: m88200 の内部の BATC/PATC サーチ方法を ver 0.6.1 のものに戻す。
+<li>m88k(Update): m88200 の内部の BATC/PATC サーチ方法を ver 0.6.1 のものに戻す。
  <q>Revert the search method inside the BATC/PATC to that of ver 0.6.1.</q>
-<li>vm: 内蔵 LUNA-88K PROM の割り込みハンドラを整備。
+<li>vm(Update): 内蔵 LUNA-88K PROM の割り込みハンドラを整備。
  OpenBSD/luna88k の /boot の hexdump コマンドがバスエラー領域でハングアップ
  していたのが直ります。
  <q>Implement an interrupt handler in the builtin emulated PROM on LUNA-88K.
  This fixes the issue where the hexdump command on the OpenBSD/luna88k boot
  loader was hanging when accessing the bus error region.</q>
-<li>vm: LUNA-88K のメモリマップを全体的に更新。実機に近づける。
+<li>vm(Update): LUNA-88K のメモリマップを全体的に更新。実機に近づける。
  <q>Modify and adjust the memory map on LUNA-88K.</q>
-<li>vm: SCSI バスでセレクションフェーズからメッセージアウトフェーズへの移行を
+<li>vm(New): SCSI バスでセレクションフェーズからメッセージアウトフェーズへの移行を
  実装。
  これで UniOS Mach 起動中に nono が不正終了していたのは直ります(まだ動きません)。
  <q>Implement the SCSI bus transition from the selection phase to
  the message out phase.
  This fixes the abnormal termination while booting UniOS Mach.
  (But it doesn't work yet.)</q>
-<li>vm: 書き込み禁止の SCSI イメージファイルの扱いを変更。
+<li>vm(Fix): 書き込み禁止の SCSI イメージファイルの扱いを変更。
  <q>Change the handling of write-protected SCSI image files.</q>
-<li>vm: ソフトウェアキーボードを LUNA-88K に対応(?)。
+<li>vm(New): ソフトウェアキーボードを LUNA-88K に対応(?)。
 それに伴い LUNA-I、X68030 の一部の内部キーコードも変更。
  <q>Support the LUNA-88K software keyboard(?).  As a result of this,
  several internal keycodes on LUNA-I and X68030 are also moved.</q>
-<li>debugger: ブレークポイントモニタを m88k に対応。
+<li>debugger(Update): ブレークポイントモニタを m88k に対応。
  <q>The breakpoint monitor now supports m88k.</q>
-<li>debugger: ブレークポイントモニタの命令ブレークポイントを 1バイト命令
+<li>debugger(Update): ブレークポイントモニタの命令ブレークポイントを 1バイト命令
 (HD64180) にも対応。
  <q>The breakpoint monitor now supports 1-byte instructions like HD64180.</q>
-<li>debugger: ブレークポイントの CPU 名が正しくない場合に不正終了する場合があったのを修正。
+<li>debugger(Fix): ブレークポイントの CPU 名が正しくない場合に不正終了する場合があったのを修正。
  <q>Fix the abnormal termination when a breakpoint has an invalid CPU name.</q>
-<li>debugger: ベクタテーブルを LUNA-88K に対応。
+<li>debugger(Update): ベクタテーブルを LUNA-88K に対応。
  <q>The vector table now supports LUNA-88K.</q>
-<li>debugger: bv コマンドの書式を変更。
+<li>debugger(Update): bv コマンドの書式を変更。
  <q>Change the syntax of the bv command.</q>
-<li>debugger: bi コマンドで一部のニーモニック表記を実装。
+<li>debugger(Update): bi コマンドで一部のニーモニック表記を実装。
  <q>The bi command supports some mnemonics.</q>
-<li>debugger: --bi オプション、--bv オプションを実装。
+<li>debugger(New): --bi オプション、--bv オプションを実装。
  <q>Implement --bi and --bv options.</q>
-<li>util/nvramedit: NVRAM.DAT のファイルサイズを修正。
+<li>util/nvramedit(Fix): NVRAM.DAT のファイルサイズを修正。
  <q>Fix the file size of NVRAM.DAT.</q>
 </ul><p>
 
