@@ -33,7 +33,7 @@
 
 // XXX mul/div/divu 命令の FPU disabled のケースは未検査
 
-#include "header.h"
+#include "nono.h"
 #include "mystring.h"
 #include <assert.h>
 #include <sys/stat.h>
@@ -144,6 +144,7 @@ static constexpr uint32 ntor(uint32 n) {
 	if (n == 1) return 8;
 	if (n == 2) return 10;
 	if (n == 3) return 12;
+	__unreachable();
 }
 static constexpr uint32 R3(uint32 d, uint32 s1, uint32 s2) {
 	d  = ntor(d);
