@@ -10,6 +10,7 @@
 
 #include "mpu64180.h"
 #include "debugger.h"
+#include "event.h"
 #include "hd64180.h"
 #include "hd647180.h"
 #include "scheduler.h"
@@ -19,7 +20,7 @@
 #include "hd64180ops.cpp"
 
 void
-MPU64180Device::ExecNormal(Event& ev)
+MPU64180Device::ExecNormal(Event *ev)
 {
 	uint64 cycle_start = used_cycle;
 
@@ -59,7 +60,7 @@ MPU64180Device::ExecNormal(Event& ev)
 	}
 
 	int cycle = used_cycle - cycle_start;
-	ev.time = cycle * clock_nsec;
+	ev->time = cycle * clock_nsec;
 	scheduler->StartEvent(ev);
 }
 
