@@ -15,14 +15,14 @@
 
 class ConsoleDevice;
 
-class COMDriverCons : public COMDriver
+class COMDriverConsole : public COMDriver
 {
 	using inherited = COMDriver;
  public:
-	explicit COMDriverCons(HostDevice *hostdev_);
-	~COMDriverCons() override;
+	explicit COMDriverConsole(HostDevice *hostdev_);
+	~COMDriverConsole() override;
 
-	bool InitDriver() override;
+	bool InitDriver(bool startup) override;
 	int Read() override;
 	void Write(uint32 data) override;
 
