@@ -36,7 +36,7 @@ Driver::~Driver()
 
 // ドライバ初期化
 bool
-Driver::InitDriver()
+Driver::InitDriver(bool startup)
 {
 	putmsg(1, "created");
 	return true;
