@@ -210,7 +210,7 @@ HostCOMDevice::SelectDriver(bool startup)
 		} else {
 			// UI に通知してフォールバック。
 			int n = (key == "debugger") ? -1 : GetId() - OBJ_HOSTCOM0;
-			UIMessage::Post(UIMessage::HOSTCOM_FAILED, n);
+			gMainApp.GetUIMessage()->Post(UIMessage::HOSTCOM_FAILED, n);
 
 			CreateNone();
 		}
