@@ -14,6 +14,8 @@
 #include "comdriver.h"
 #include "spscqueue.h"
 
+class ConfigItem;
+
 class HostCOMDevice : public HostDevice
 {
 	using inherited = HostDevice;
@@ -33,7 +35,7 @@ class HostCOMDevice : public HostDevice
 	};
 
  public:
-	HostCOMDevice(Device *parent_, const std::string& objname_);
+	HostCOMDevice(Device *parent_, int n, const std::string& portname_);
 	~HostCOMDevice() override;
 
 	void SetLogLevel(int loglevel_) override;
@@ -43,11 +45,18 @@ class HostCOMDevice : public HostDevice
 	bool Tx(uint32 data);
 	uint32 Rx();
 
+	// ドライバ名を返す。
+	const std::string GetDriverName();
+
  private:
-	bool SelectDriver();
+	bool SelectDriver(bool startup) override;
+	void CreateNone();
+	void CreateStdio(const ConfigItem&, const std::string& key);
+	void CreateTCP();
+	void CreateConsole(const ConfigItem&);
 
 	int Read() override;
-	void Write(uint32 data) override;
+	void Write() override;
 
 	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
 
