@@ -267,7 +267,7 @@ HostNetDevice::SelectDriver(bool startup)
 		} else {
 			// UI に通知してフォールバック。
 			int n = GetId() - OBJ_HOSTNET0;
-			UIMessage::Post(UIMessage::HOSTNET_FAILED, n);
+			gMainApp.GetUIMessage()->Post(UIMessage::HOSTNET_FAILED, n);
 
 			CreateNone();
 		}
