@@ -23,7 +23,7 @@ class NetDriverAFPacket : public NetDriver
 	NetDriverAFPacket(HostDevice *hostdev_, const std::string& ifname_);
 	~NetDriverAFPacket() override;
 
-	bool InitDriver() override;
+	bool InitDriver(bool startup) override;
 	int Read(NetPacket *p) override;
 	void Write(const void *buf, int buflen) override;
 
