@@ -20,7 +20,7 @@ class NetDriverBPF : public NetDriver
 	NetDriverBPF(HostDevice *hostdev_, const std::string& ifname_);
 	~NetDriverBPF() override;
 
-	bool InitDriver() override;
+	bool InitDriver(bool startup) override;
 
 	int Read(NetPacket *p) override;
 	void Write(const void *buf, int buflen) override;
