@@ -90,7 +90,7 @@ class Object
 	// 通常、オブジェクト名はコンストラクタで指定するが、コンストラクタ時点
 	// ではまだ名前が決まらないような場合にだけ使う。
 	// こちらはエイリアスには関与しない。
-	void SetName(const std::string& newname) {
+	virtual void SetName(const std::string& newname) {
 		objname = newname;
 	}
 
