@@ -779,8 +779,9 @@ m88200::InvalidatePATCCmd()
 			int i = __builtin_ctzll(pi);
 			m88200PATC& p = patc[i];
 			if (p.lpa == addr) {
-				InvalidatePATCHash(i);
 				p.lpa |= PATC_INVALID;
+				InvalidatePATCHash(i);
+				patc_free |= 1ULL << i;
 				STAT(stat_patc_invalidate);
 				// 1本ヒットすればこれ以上一致することはないはず。
 				break;
@@ -813,8 +814,9 @@ m88200::InvalidatePATCCmd()
 			if ((p.lpa & mask) == addr) {
 				// 無効化
 				// XXX 削除した結果穴が空いても詰める処理は未実装
-				InvalidatePATCHash(i);
 				p.lpa |= PATC_INVALID;
+				InvalidatePATCHash(i);
+				patc_free |= 1ULL << i;
 				STAT(stat_patc_invalidate);
 			}
 		}
@@ -1167,7 +1169,7 @@ m88200::MBusXmem(busaddr paddr, uint32 data)
 // アクセス関数
 //
 
-template <uint size> uint64
+template <uint size> busdata
 m88200::load(uint32 addr)
 {
 	acc_laddr = addr;
@@ -1175,93 +1177,84 @@ m88200::load(uint32 addr)
 	if (__predict_false(Translate() == false)) {
 		putlog(2, "Translation BusError %c:$%08x",
 			(IsSuper() ? 'S' : 'U'), acc_laddr);
-		return (uint64)-1;
+		return BusData::BusErr;
 	}
 
 	busaddr baddr = busaddr(acc_paddr) | acc_super | busaddr::Size(size);
 	busdata bd = PhysRead(baddr, acc_stat);
-	if (__predict_false(bd.IsBusErr())) {
-		return (uint64)-1;
-	}
-	return bd.Data();
+	return bd;
 }
 
-uint64
+busdata
 m88200::load_1(uint32 addr)
 {
 	return load<1>(addr);
 }
 
-uint64
+busdata
 m88200::load_2(uint32 addr)
 {
 	return load<2>(addr);
 }
 
-uint64
+busdata
 m88200::load_4(uint32 addr)
 {
 	return load<4>(addr);
 }
 
-template <uint size> uint64
+template <uint size> busdata
 m88200::store(uint32 addr, uint32 data)
 {
 	acc_laddr = addr;
 	acc_read  = false;
 	if (__predict_false(Translate() == false)) {
-		return (uint64)-1;
+		return BusData::BusErr;
 	}
 
 	busaddr baddr = busaddr(acc_paddr) | acc_super | busaddr::Size(size);
 	busdata r = PhysWrite(baddr, data, acc_stat);
-	if (__predict_false(r.IsBusErr())) {
-		return (uint64)-1;
-	}
-	return 0;
+	return r;
 }
 
-uint64
+busdata
 m88200::store_1(uint32 addr, uint32 data)
 {
 	return store<1>(addr, data);
 }
 
-uint64
+busdata
 m88200::store_2(uint32 addr, uint32 data)
 {
 	return store<2>(addr, data);
 }
 
-uint64
+busdata
 m88200::store_4(uint32 addr, uint32 data)
 {
 	return store<4>(addr, data);
 }
 
-template <uint size> uint64
+template <uint size> busdata
 m88200::xmem(uint32 addr, uint32 data)
 {
 	acc_laddr = addr;
 	acc_read  = false;
 	if (__predict_false(Translate() == false)) {
-		return (uint64)-1;
+		return BusData::BusErr;
 	}
 
 	busdata bd = CacheXmem(acc_paddr, data, size);
-	if (__predict_false(bd.IsBusErr())) {
-		return (uint64)-1;
-	}
-	return bd.Data();
+	return bd;
 }
 
-uint64
+busdata
 m88200::xmem_1(uint32 addr, uint32 data)
 {
 	return xmem<1>(addr, data);
 }
 
-uint64
+busdata
 m88200::xmem_4(uint32 addr, uint32 data)
 {
 	return xmem<4>(addr, data);
@@ -1736,18 +1729,30 @@ m88200::InvalidatePATCHash(int patc_index)
 void
 m88200::CreatePATCEntry()
 {
-	// 空きがあろうがなかろうが、とにかく一番古いエントリを使う。
-	// おそらく実機も空きエントリを前に詰めるような複雑な処理はして
-	// ないだろうという推測。
-	// 検索はハッシュを使って実装してあるため、途中に空きエントリが
+	// 空きエントリがあればそれを使う。なければ一番古いエントリを使う。
+	// 検索は線形探索ではなくハッシュで実装してあるので、途中に空きエントリが
 	// あっても (線形探索する時のような) デメリットはない。
+	// 最初は全エントリが空きで、エントリが埋まるまでは patc_next は使われない。
+	// 一度エントリが埋まると patc_next が生贄になる。
 
 	STAT(stat_patc_create);
-	m88200PATC& p = patc[patc_next];
-	// 有効なら無効化
-	if (p.IsValid()) {
-		InvalidatePATCHash(patc_next);
+
+	uint pi;
+	if (patc_free != 0) {
+		// 空きがあればそれを使う。
+		pi = __builtin_ctzll(patc_free);
+		patc_free &= ~(1ULL << pi);
+	} else {
+		// 空きがなければ FIFO。
+		pi = patc_next;
+		if (__predict_false(++patc_next >= patc.size())) {
+			patc_next = 0;
+		}
+
+		// 有効なはず。
+		InvalidatePATCHash(pi);
 	}
+	m88200PATC& p = patc[pi];
 
 	// このエントリを潰して作る
 	memset(&p, 0, sizeof(p));
@@ -1762,13 +1767,8 @@ m88200::CreatePATCEntry()
 		stat2str(p.stat).c_str());
 
 	uint64 hashkey = patc_hash_func(p.lpa);
-	uint64 bit = 1ULL << patc_next;
+	uint64 bit = 1ULL << pi;
 	patc_hash[hashkey] |= bit;
-
-	patc_next++;
-	if (__predict_false(patc_next >= patc.size())) {
-		patc_next = 0;
-	}
 }
 
 // アドレス変換 (デバッガ用)
