@@ -11,7 +11,6 @@
 #pragma once
 
 #include "device.h"
-#include "event.h"
 
 class DMACDevice;
 class PPIDevice;
@@ -53,7 +52,7 @@ class ADPCMDevice : public IODevice
  private:
 	void StartPlay();
 
-	void EventCallback(Event&);
+	void EventCallback(Event *);
 
 	bool playing {};
 	bool dack {};
@@ -63,7 +62,7 @@ class ADPCMDevice : public IODevice
 	DMACDevice *dmac {};
 	PPIDevice *ppi {};
 
-	Event event { this };
+	Event *event {};
 };
 
 static inline ADPCMDevice *GetADPCMDevice() {
