@@ -20,6 +20,7 @@
 // BusIO は使わず自力で処理する。ログの観点からもこのほうが都合がいい。
 
 #include "crtc.h"
+#include "event.h"
 #include "mfp.h"
 #include "monitor.h"
 #include "scheduler.h"
@@ -36,7 +37,7 @@ CRTCDevice::CRTCDevice()
 {
 	monitor = gMonitorManager->Regist(ID_MONITOR_CRTC, this);
 	monitor->func = ToMonitorCallback(&CRTCDevice::MonitorUpdate);
-	monitor->SetSize(62, 14);
+	monitor->SetSize(79, 27);
 }
 
 // デストラクタ
@@ -52,22 +53,23 @@ CRTCDevice::Init()
 	tvram = GetTVRAMDevice();
 	videoctlr = GetVideoCtlrDevice();
 
-	hsync_event.func = ToEventCallback(&CRTCDevice::HSyncCallback);
-	hsync_event.SetName("CRTC H-Sync");
-	vdisp_event.func = ToEventCallback(&CRTCDevice::VDispCallback);
-	vdisp_event.SetName("CRTC V-Disp");
-	scheduler->RegistEvent(hsync_event);
-	scheduler->RegistEvent(vdisp_event);
+	auto evman = GetEventManager();
+	hsync_event = evman->Regist(this,
+		ToEventCallback(&CRTCDevice::HSyncCallback),
+		"CRTC H-Sync");
+	vdisp_event = evman->Regist(this,
+		ToEventCallback(&CRTCDevice::VDispCallback),
+		"CRTC V-Disp");
 
 	// ラスターコピーは実際には CRTC の機能ではなく TVRAM (VRAM チップ) の
 	// 機能だが、イベントの時間管理が発生するのは CRTC 側なのでここで管理。
 	// X68030 搭載の VRAM チップは HM514402A だが、ここでは X68000 XVI 搭載の
 	// HM53461 の値を使用し、これが最小 190nsec * 2 らしいので
 	// とりあえず 400nsec としておく。
-	raster_event.func = ToEventCallback(&CRTCDevice::RasterCallback);
-	raster_event.time = 400_nsec;
-	raster_event.SetName("CRTC Raster Copy");
-	scheduler->RegistEvent(raster_event);
+	raster_event = evman->Regist(this,
+		ToEventCallback(&CRTCDevice::RasterCallback),
+		"CRTC Raster Copy");
+	raster_event->time = 400_nsec;
 
 	return true;
 }
@@ -81,11 +83,11 @@ CRTCDevice::ResetHard(bool poweron)
 
 	// XXX 適当
 	// すぐに水平同期と垂直帰線期間を開始する
-	hsync_event.time = 0;
-	hsync_event.code = 1;
+	hsync_state = 1;
+	hsync_event->time = 0;
 	scheduler->RestartEvent(hsync_event);
-	vdisp_event.time = 0;
-	vdisp_event.code = 1;
+	vdisp_state = 1;
+	vdisp_event->time = 0;
 	scheduler->RestartEvent(vdisp_event);
 }
 
@@ -235,6 +237,30 @@ CRTCDevice::Peek2(uint32 addr) const
 	return data;
 }
 
+// 今の所、標準設定しかサポートしていないので、違う時だけログを出したりする。
+static const uint16 crtc_supported[] = {
+	0x0089,	// R00
+	0x000e,	// R01
+	0x001c,	// R02
+	0x007c,	// R03
+	0x0237,	// R04
+	0x0005,	// R05
+	0x0028,	// R06
+	0x0228,	// R07
+	0,		// R08
+	0,		// R09
+	0,		// R10
+	0,		// R11
+	0x0000,	// R12
+	0x0000,	// R13
+	0x0000,	// R14
+	0x0000,	// R15
+	0x0000,	// R16
+	0x0000,	// R17
+	0x0000,	// R18
+	0x0000,	// R19
+};
+
 void
 CRTCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 {
@@ -257,31 +283,47 @@ CRTCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 	screen.Print(0, y++, "R10:$%04x (Text ScrollX)", crtc.r[10]);
 	screen.Print(0, y++, "R11:$%04x (Text ScrollY)", crtc.r[11]);
 
+	screen.Print(0, y++, "R12:$%04x (Grp. Page0 X)", crtc.r[12]);
+	screen.Print(0, y++, "R13:$%04x (Grp. Page0 Y)", crtc.r[13]);
+	screen.Print(0, y++, "R14:$%04x (Grp. Page1 X)", crtc.r[14]);
+	screen.Print(0, y++, "R15:$%04x (Grp. Page1 Y)", crtc.r[15]);
+	screen.Print(0, y++, "R16:$%04x (Grp. Page2 X)", crtc.r[16]);
+	screen.Print(0, y++, "R17:$%04x (Grp. Page2 Y)", crtc.r[17]);
+	screen.Print(0, y++, "R18:$%04x (Grp. Page3 X)", crtc.r[18]);
+	screen.Print(0, y++, "R19:$%04x (Grp. Page3 Y)", crtc.r[19]);
+
+	for (uint i = 0; i < countof(crtc_supported); i++) {
+		if (8 <= i && i < 12) {
+			continue;
+		}
+		if (crtc.r[i] != crtc_supported[i]) {
+			screen.Print(29, (i < 8 ? i : i - 2), TA::On,
+				"(not supported value)");
+		}
+	}
+
+	//  3         4         5         6         7
+	// 90123456789012345678901234567890123456789012345678
+	// SIZ=1024x1024 COL=65536 HF=31kHz VD=undef HD=50MHz
 	val = crtc.r[20];
 	screen.Print(0, y,   "R20:$%04x (Mode)", val);
-	screen.Print(29, y, TA::OnOff(val & CRTC::R20_MEM), "MEM");
-	static const char * const r20col_str[] = {
-		"16",
-		"256",
-		"undef",
-		"65536",
-	};
-	screen.Print(33, y, "COL=%s", r20col_str[(val >> 8) & 3]);
-	screen.Print(43, y, TA::OnOff(val & CRTC::R20_HF), "HF");
+	screen.Print(29, y, "SIZ=%s", VideoCtlrDevice::siz_str[(val >> 10) & 1]);
+	screen.Print(43, y, "COL=%s", VideoCtlrDevice::col_str[(val >>  8) & 3]);
+	screen.Print(53, y, "HF=%ukHz", 15 + (val & 0x10));
 	static const char * const r20vd_str[] = {
 		"256",
 		"512",
 		"1024",
 		"undef",
 	};
-	screen.Print(46, y, "VD=%s", r20vd_str[(val >> 2) & 3]);
+	screen.Print(62, y, "VD=%s", r20vd_str[(val >> 2) & 3]);
 	static const char * const r20hd_str[] = {
 		"256",
 		"512",
 		"768",
 		"50MHz",
 	};
-	screen.Print(55, y, "HD=%s", r20hd_str[val & 3]);
+	screen.Print(71, y, "HD=%s", r20hd_str[val & 3]);
 	y++;
 
 	val = crtc.r[21];
@@ -304,6 +346,11 @@ CRTCDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 		val, (val >> 8), (val & 0xff));
 
 	screen.Print(0, y++, "R23:$%04x (Text Access Mask)", crtc.r[23]);
+
+	// ビデオコントローラもここに並べたほうが読みやすいか。
+	y++;
+	screen.Puts(0, y++, "<Video Controller>");
+	videoctlr->MonitorUpdate(screen, y, crtc.r[20]);
 }
 
 // CRTC レジスタへの書き込み。
@@ -314,31 +361,38 @@ CRTCDevice::SetReg(uint32 reg, uint32 data)
 	crtc.r[reg] = data;
 
 	switch (reg) {
+	 case CRTC::R00 ... CRTC::R07:
+	 case CRTC::R12 ... CRTC::R19:
+		if (crtc.r[reg] == crtc_supported[reg]) {
+			putlog(2, "R%02u <- $%04x", reg, data);
+			return;
+		}
+		break;
 	 case CRTC::R10:
 		putlog(2, "R%02u <- $%04x", reg, data);
 		tvram->SetScrollX(crtc.r[10]);
-		break;
+		return;
 	 case CRTC::R11:
 		putlog(2, "R%02u <- $%04x", reg, data);
 		tvram->SetScrollY(crtc.r[11]);
-		break;
+		return;
 	 case CRTC::R21:
 		// 頻度が高いのでログレベルを上げておく
 		putlog(3, "R%02u <- $%04x", reg, data);
 		tvram->SetAccessPlane(crtc.r[21]);
-		break;
+		return;
 	 case CRTC::R22:
 		putlog(3, "R%02u <- $%04x", reg, data);
-		break;
+		return;
 	 case CRTC::R23:
 		// 頻度が高いのでログレベルを上げておく
 		putlog(3, "R%02u <- $%04x", reg, data);
 		tvram->SetAccessMask(crtc.r[23]);
-		break;
+		return;
 	 default:
-		putlog(2, "R%02u <- $%04x (NOT IMPLEMENTED)", reg, data);
 		break;
 	}
+	putlog(0, "R%02u <- $%04x (NOT IMPLEMENTED)", reg, data);
 }
 
 // 動作ポートへの書き込み。
@@ -373,19 +427,19 @@ CRTCDevice::WriteOp(uint32 data)
 
 // 水平同期イベント
 void
-CRTCDevice::HSyncCallback(Event& ev)
+CRTCDevice::HSyncCallback(Event *ev)
 {
-	switch (ev.code) {
+	switch (hsync_state) {
 	 case 0:	// フロントポーチ
 		// フロントポーチ
-		ev.time = 2.07_usec;
-		ev.code++;
+		ev->time = 2.07_usec;
+		hsync_state++;
 		break;
 
 	 case 1:	// 水平同期パルス
 		// 水平同期期間
-		ev.time = 3.45_usec;
-		ev.code++;
+		ev->time = 3.45_usec;
+		hsync_state++;
 
 		// GPIP の状態を更新
 		mfp->SetHSync(true);
@@ -405,12 +459,15 @@ CRTCDevice::HSyncCallback(Event& ev)
 
 	 case 2:	// バックポーチ + 表示期間
 		// バックポーチ + Hdisp
-		ev.time = 4.14_usec + 22.09_usec;
-		ev.code = 0;
+		ev->time = 4.14_usec + 22.09_usec;
+		hsync_state = 0;
 
 		// GPIP の状態を更新
 		mfp->SetHSync(false);
 		break;
+
+	 default:
+		__unreachable();
 	}
 
 	scheduler->StartEvent(ev);
@@ -418,37 +475,35 @@ CRTCDevice::HSyncCallback(Event& ev)
 
 // ラスターコピー完了イベント
 void
-CRTCDevice::RasterCallback(Event& ev)
+CRTCDevice::RasterCallback(Event *ev)
 {
 	// 終わったら動作ポートの RC ビットを %0 にする?
 	crtc.op &= ~CRTC::OP_RC;
 }
 
 // 垂直表示・帰線イベント
-// ev.code が 1 なら表示期間開始(V-disp)、0 なら帰線期間開始(V-blank)。
+// vdisp_state が 1 なら表示期間開始(V-disp)、0 なら帰線期間開始(V-blank)。
 void
-CRTCDevice::VDispCallback(Event& ev)
+CRTCDevice::VDispCallback(Event *ev)
 {
-	int vdisp = ev.code;
-
 	// GPIP の状態を更新
-	mfp->SetVDisp(vdisp);
+	mfp->SetVDisp(vdisp_state);
 
 	// 今はここで1画面まるごと作成
-	if (vdisp) {
+	if (vdisp_state) {
 		videoctlr->VDisp();
 	}
 
 	// 次のタイミングを計算
 	// XXX まだ CRTC から計算していない
-	if (vdisp) {
+	if (vdisp_state) {
 		// 垂直表示期間
-		ev.time = 16250_usec;
-		ev.code = 0;
+		ev->time = 16250_usec;
+		vdisp_state = 0;
 	} else {
 		// 垂直帰線期間
-		ev.time = 191_usec + 1111_usec + 476_usec;
-		ev.code = 1;
+		ev->time = 191_usec + 1111_usec + 476_usec;
+		vdisp_state = 1;
 	}
 	scheduler->StartEvent(ev);
 }
