@@ -11,7 +11,6 @@
 #pragma once
 
 #include "device.h"
-#include "event.h"
 
 class LunafbDevice;
 class Renderer;
@@ -36,7 +35,7 @@ class CRTC2Device : public IODevice
 
  private:
 	// 垂直表示期間イベント
-	void VDispCallback(Event& ev);
+	void VDispCallback(Event *);
 
 	// アドレスレジスタ
 	uint ar {};
@@ -44,8 +43,10 @@ class CRTC2Device : public IODevice
 	// レジスタ
 	uint8 reg[40] {};
 
+	uint vdisp_state {};
+
 	LunafbDevice *lunafb {};
 	Renderer *renderer {};
 
-	Event vdisp_event { this };
+	Event *vdisp_event {};
 };
