@@ -45,7 +45,7 @@ class EthernetDevice : public IODevice
 
  protected:
 	// ホストスレッドからの受信通知
-	void HostRxCallback();
+	void HostRxCallback(uint32);
 
 	std::unique_ptr<HostNetDevice> hostnet /*{}*/;
 };
