@@ -18,6 +18,7 @@
 
 #include "fdd.h"
 #include "config.h"
+#include "event.h"
 #include "fdc.h"
 #include "mainapp.h"
 #include "pedec.h"
@@ -117,9 +118,10 @@ FDDDevice::Init()
 	scheduler->ConnectMessage(MessageID::FDD_UNLOAD(unit), this,
 		ToMessageCallback(&FDDDevice::UnloadMessage));
 
-	event.func = ToEventCallback(&FDDDevice::EventCallback);
-	event.SetName(GetName());
-	scheduler->RegistEvent(event);
+	auto evman = GetEventManager();
+	event = evman->Regist(this,
+		ToEventCallback(&FDDDevice::EventCallback),
+		GetName());
 
 	// オープン前に writeignore をチェック。
 	// この後パス名を処理するとすぐに UI に通知を出すため、それより前で
@@ -133,10 +135,6 @@ FDDDevice::Init()
 		if (LoadDisk(path) == false) {
 			return false;
 		}
-	} else {
-		// メディアがロードされないままでも起動時は必ず通知を投げる。
-		// ステータスパネルはこの UIMessage でのみ状態を更新するため。
-		MediaChanged();
 	}
 
 	return true;
@@ -298,7 +296,7 @@ FDDDevice::SetMotorOn(bool motor_on_)
 }
 
 void
-FDDDevice::EventCallback(Event& ev)
+FDDDevice::EventCallback(Event *ev)
 {
 	// モータが回転している間は1バイトずつ進める
 	pos++;
@@ -313,31 +311,31 @@ FDDDevice::EventCallback(Event& ev)
 
 	 case SPIN_UP:
 		// 増速中
-		if (event.time == 16_usec) {
+		if (event->time == 16_usec) {
 			motor_state = READY;
 			// READY になったので FDC に通知
 			fdc->ReadyChanged(unit, true);
 		} else {
-			if (event.time < 16_usec) {
+			if (event->time < 16_usec) {
 				// オーバーシュート対応
-				event.time = 16_usec;
+				event->time = 16_usec;
 			} else {
-				event.time /= 2;
+				event->time /= 2;
 			}
-			putlog(4, "SPIN_UP next=%uusec", (uint)(event.time / 1_usec));
+			putlog(4, "SPIN_UP next=%uusec", (uint)(event->time / 1_usec));
 		}
 		scheduler->StartEvent(ev);
 		break;
 
 	 case SPIN_DOWN:
-		if (event.time >= 262144_usec) {
+		if (event->time >= 262144_usec) {
 			motor_state = STOPPED;
 			// イベント停止、ここでは time も 0 クリアしておく。
-			event.time = 0;
+			event->time = 0;
 		} else {
-			event.time *= 2;
+			event->time *= 2;
 			scheduler->StartEvent(ev);
-			putlog(4, "SPIN_DOWN next=%uusec", (uint)(event.time / 1_usec));
+			putlog(4, "SPIN_DOWN next=%uusec", (uint)(event->time / 1_usec));
 		}
 		break;
 
@@ -390,8 +388,8 @@ FDDDevice::DoMotorOn()
 		// 仕様では 500msec で READY になるとあるが、ここでは 2 のべき乗を
 		// 使っているので、約 524msec かかる。細かいことは気にしない。
 		motor_state = SPIN_UP;
-		event.time = 262144_usec;
-		putlog(4, "SPIN_UP next=%uusec", (uint)(event.time / 1_usec));
+		event->time = 262144_usec;
+		putlog(4, "SPIN_UP next=%uusec", (uint)(event->time / 1_usec));
 	} else if (motor_state == SPIN_DOWN) {
 		// 細かいことは無視して、増速に転じる
 		motor_state = SPIN_UP;
@@ -787,7 +785,7 @@ FDDDevice::Clear()
 void
 FDDDevice::MediaChanged() const
 {
-	UIMessage::Post(UIMessage::FDD_MEDIA_CHANGE, unit);
+	gMainApp.GetUIMessage()->Post(UIMessage::FDD_MEDIA_CHANGE, unit);
 }
 
 // メディアを挿入する。
@@ -813,7 +811,7 @@ FDDDevice::LoadMessage(MessageID msgid, uint32 arg)
 {
 	if (LoadDisk(new_pathname) == false) {
 		// 失敗したら UI に通知
-		UIMessage::Post(UIMessage::FDD_MEDIA_FAILED);
+		gMainApp.GetUIMessage()->Post(UIMessage::FDD_MEDIA_FAILED);
 	}
 }
 
