@@ -100,6 +100,7 @@
 
 #include "keyboard.h"
 #include "config.h"
+#include "mainapp.h"
 #include "scheduler.h"
 #include "syncer.h"
 #include "uimessage.h"
@@ -141,7 +142,13 @@ Keyboard::~Keyboard()
 bool
 Keyboard::Init()
 {
-	syncer = GetSyncer();
+	// LUNA ならスケジューラとの連携が必要。
+	// キーリピートをソフトウェアで処理しないといけないため。
+	if (gMainApp.Has(VMCap::LUNA)) {
+		syncer = GetSyncer();
+	}
+
+	uimessage = gMainApp.GetUIMessage();
 
 	scheduler->ConnectMessage(MessageID::KEY_INPUT, this,
 		ToMessageCallback(&Keyboard::KeyInputMessage));
@@ -162,7 +169,7 @@ Keyboard::ResetHard(bool poweron)
 		}
 
 		// キー通知
-		syncer->RequestKeyPressed(Any());
+		SyncKeyPressed(Any());
 	}
 
 	// 内部状態をリセット
@@ -180,7 +187,7 @@ Keyboard::PowerOff()
 	std::fill(pressed.begin(), pressed.end(), false);
 
 	// キーが全部解放されたので通知
-	syncer->RequestKeyPressed(false);
+	SyncKeyPressed(false);
 
 	DoDisconnect();
 }
@@ -288,7 +295,7 @@ Keyboard::DoConnect()
 	}
 
 	// UI に通知する
-	UIMessage::Post(UIMessage::KEYBOARD);
+	uimessage->Post(UIMessage::KEYBOARD);
 }
 
 void
@@ -302,7 +309,7 @@ Keyboard::DoDisconnect()
 	MDDisconnect();
 
 	// UI に通知する
-	UIMessage::Post(UIMessage::KEYBOARD);
+	uimessage->Post(UIMessage::KEYBOARD);
 }
 
 // キーの押し下げ状態を設定する。
@@ -316,16 +323,26 @@ Keyboard::SetPressed(uint keycode, bool ismake)
 		bool prev = Any();
 		pressed[keycode] = true;
 		if (prev == false) {
-			syncer->RequestKeyPressed(true);
+			SyncKeyPressed(true);
 		}
 	} else {
 		pressed[keycode] = false;
 		if (Any() == false) {
-			syncer->RequestKeyPressed(false);
+			SyncKeyPressed(false);
 		}
 	}
 }
 
+// LUNA なら、キーの押し下げ状態 (いずれかでも押し下げなら true) を
+// syncer にも通知する。
+void
+Keyboard::SyncKeyPressed(bool any_pressed)
+{
+	if (syncer) {
+		syncer->RequestKeyPressed(any_pressed);
+	}
+}
+
 // キー入力を1つ処理する。
 // keystat が押下・開放されたキーの物理的な状態。
 // キー入力を受け取らずに破棄した場合は false を返す。
@@ -390,7 +407,7 @@ Keyboard::KeyInputCommon(uint keystat)
 	} else {
 		arg = 0;
 	}
-	UIMessage::Post(UIMessage::KEYBOARD, arg);
+	uimessage->Post(UIMessage::KEYBOARD, arg);
 
 	// LUNA の LED キー消灯はキー開放を送信
 	if (ledflag == KC_FLAG_LED_BREAK) {
