@@ -15,6 +15,7 @@
 #include "message.h"
 
 class Syncer;
+class UIMessage;
 
 // 文字入力しか持たないキーボードの下位クラス。
 class DumbKeyboard : public Device
@@ -111,6 +112,9 @@ class Keyboard : public DumbKeyboard
 	// キーの押し下げ状態を設定する
 	void SetPressed(uint keycode, bool ismake);
 
+	// キーの押し下げ状態を Syncer に通知する
+	void SyncKeyPressed(bool pressed);
+
 	// キーを処理する (共通部分)
 	bool KeyInputCommon(uint keystat);
 
@@ -146,6 +150,7 @@ class Keyboard : public DumbKeyboard
 	bool prev_m {};
 
 	Syncer *syncer {};
+	UIMessage *uimessage {};
 
  private:
 	void KeyInputMessage(MessageID, uint32);
