@@ -11,7 +11,6 @@
 #pragma once
 
 #include "keyboard.h"
-#include "event.h"
 
 class SIODevice;
 
@@ -54,7 +53,7 @@ class LunaKeyboard : public Keyboard
 	void Start(uint64 period);
 
 	// コールバック
-	void Callback(Event& ev);
+	void Callback(Event *);
 
 	// 共通キーコードから LED 番号を取得。
 	// 0: かな
@@ -79,7 +78,7 @@ class LunaKeyboard : public Keyboard
 	uint64 buzzer_end {};		// ブザーを鳴らし終わる仮想時刻
 
 	// イベント
-	Event event { this };
+	Event *event {};
 
 	Monitor *monitor {};
 
