@@ -12,7 +12,6 @@
 
 #include "mpu.h"
 #include "branchhistory.h"
-#include "event.h"
 #include "hd64180.h"
 #include "message.h"
 #include <array>
@@ -101,10 +100,10 @@ class MPU64180Device : public MPUDevice, private HD64180
 	void EnterNormal();
 	void EnterSleep();
 	void EnterWakeup();
-	void ExecTrace(Event& ev);
-	void ExecNormal(Event& ev);
-	void ExecSleep(Event& ev);
-	void ExecWakeup(Event& ev);
+	void ExecTrace(Event *);
+	void ExecNormal(Event *);
+	void ExecSleep(Event *);
+	void ExecWakeup(Event *);
 	void SetExec(EventCallback_t);
 
 	// トレース設定。デバッガから呼び出される。
@@ -208,7 +207,7 @@ class MPU64180Device : public MPUDevice, private HD64180
 	// タイマー
 	void EnableTimer();
 	void ChangeTimerInterrupt();
-	void TimerCallback(Event& ev);
+	void TimerCallback(Event *);
 	void MakeActiveTimer();
 
 	uint16 ppc {};
@@ -316,7 +315,7 @@ class MPU64180Device : public MPUDevice, private HD64180
 	EventCallback_t exec_func {};
 
 	// イベント
-	Event timer_event { this };
+	Event *timer_event {};
 
 	// 名前
 	static const char * const opmode_names[];
