@@ -11,6 +11,7 @@
 #include "mpu88xx0.h"
 #include "config.h"
 #include "debugger.h"
+#include "event.h"
 #include "m88100disasm.h"
 #include "scheduler.h"
 
@@ -146,16 +147,16 @@ MPU88xx0Device::ResetHard(bool poweron)
 	// リセット例外が起動するまでに時間がかかるというところを都合よく真似て
 	// おく。
 
-	exec_event.func = ToEventCallback(&MPU88xx0Device::ResetCallback);
-	exec_event.time = (8 + 256) * clock_nsec;
-	exec_event.SetName(GetName() + " Reset");
+	exec_event->func = ToEventCallback(&MPU88xx0Device::ResetCallback);
+	exec_event->time = (8 + 256) * clock_nsec;
+	exec_event->SetName(GetName() + " Reset");
 	scheduler->RestartEvent(exec_event);
 }
 
 // リセット例外コールバック。
 // MPU リセットから規定時間後に呼ばれる。
 void
-MPU88xx0Device::ResetCallback(Event& ev)
+MPU88xx0Device::ResetCallback(Event *ev)
 {
 	// リセット例外を実行
 	uint64 cycle_start = used_cycle;
@@ -216,15 +217,15 @@ MPU88xx0Device::ResetCallback(Event& ev)
 
 	// 以降は通常走行
 	int cycle = used_cycle - cycle_start;
-	exec_event.func = exec_normal;
-	exec_event.time = cycle * clock_nsec;
-	exec_event.SetName(GetName() + " Execute");
+	exec_event->func = exec_normal;
+	exec_event->time = cycle * clock_nsec;
+	exec_event->SetName(GetName() + " Execute");
 	scheduler->StartEvent(exec_event);
 }
 
 // トレース実行のコールバック
 void
-MPU88xx0Device::ExecTrace(Event& ev)
+MPU88xx0Device::ExecTrace(Event *ev)
 {
 	debugger->ExecMain();
 	ExecNormal(ev);
@@ -239,7 +240,7 @@ MPU88xx0Device::SetTrace(bool enable)
 	} else {
 		exec_normal = ToEventCallback(&MPU88xx0Device::ExecNormal);
 	}
-	exec_event.func = exec_normal;
+	exec_event->func = exec_normal;
 }
 
 // アクセス中の論理アドレスを取得
@@ -441,15 +442,40 @@ MPU88xx0Device::MonitorUpdate(Monitor *, TextScreen& screen)
 		((tmp.fppt >> 13) & 1) + '0',
 		((tmp.fppt >> 12) & 1) + '0',
 		((tmp.fppt >> 11) & 1) + '0',
-		tsiz[(tmp.fppt >>  9) & 3],
-		tsiz[(tmp.fppt >>  7) & 3],
-		tsiz[(tmp.fppt >>  5) & 3],
+		tsiz[(tmp.fppt >> 9) & 3],
+		tsiz[(tmp.fppt >> 7) & 3],
+		tsiz[(tmp.fppt >> 5) & 3],
 		(tmp.fppt & M88100::FPPT_DEST));
 
-	screen.Print(0, y++, "fphs1(fcr1)/fpls1(fcr2): %08x'%08x",
-		tmp.fphs1, tmp.fpls1);
-	screen.Print(0, y++, "fphs2(fcr3)/fpls2(fcr4): %08x'%08x",
-		tmp.fphs2, tmp.fpls2);
+	for (uint i = 0; i < 2; i++) {
+		uint32 hs;
+		uint32 ls;
+		bool isfloat;
+		if (i == 0) {
+			hs = tmp.fphs1;
+			ls = tmp.fpls1;
+			isfloat = (tmp.fppt & 0x600) == 0;
+		} else {
+			hs = tmp.fphs2;
+			ls = tmp.fpls2;
+			isfloat = (tmp.fppt & 0x180) == 0;
+		}
+		uint n = i * 2;
+		screen.Print(0, y, "fphs%u(fcr%u)/fpls%u(fcr%u): %08x'%08x =",
+			(i + 1), (n + 1), (i + 1), (n + 2), hs, ls);
+		int32 e = ((int32)(hs << 1)) >> 21;
+		screen.Print(45, y, "%c0.%05x'",
+			((hs & 0x80000000) ? '-' : '+'),
+			(hs & 0x000f'ffff));
+		if (isfloat) {
+			screen.Print(45 + 9,  y, "%1x", (ls >> 28) & 0xf);
+			screen.Print(45 + 10, y, TA::Disable, "%07x", (ls & 0x0fff'ffff));
+			screen.Print(45 + 18, y, "e%+d", e);
+		} else {
+			screen.Print(45 + 9, y, "%08x e%+d", ls, e);
+		}
+		y++;
+	}
 
 	screen.Print(0, y, "fprh(fcr6) /fprl(fcr7):  %08x'%08x(",
 		tmp.fprh, tmp.fprl);
