@@ -19,6 +19,7 @@
 class ConsoleDevice;
 class PlaneVRAMDevice;
 class Syncer;
+class UIMessage;
 class VideoCtlrDevice;
 
 class Renderer : public ThreadDevice
@@ -74,6 +75,8 @@ class Renderer : public ThreadDevice
 	// 画面合成。更新があれば true を返す。(派生クラス側で用意)
 	virtual bool RenderMD() = 0;
 
+	void PrintPerf();
+
 	DECLARE_MONITOR_CALLBACK(MonitorUpdate);
 
 	// ウィンドウとして表示される画面はオプションや設定などで縮尺を変える
@@ -128,6 +131,7 @@ class Renderer : public ThreadDevice
 	FixedQueue<uint64, 4> ma_output_span {};	// 出力通知間隔
 
 	Syncer *syncer {};
+	UIMessage *uimessage {};
 
 	Monitor *monitor {};
 
