@@ -10,6 +10,7 @@
 
 #include "scc.h"
 #include "bitops.h"
+#include "event.h"
 #include "hostcom.h"
 #include "keyboard.h"
 
@@ -55,14 +56,6 @@ SCCDevice::SCCDevice()
 		pclk_ns = 250_nsec;
 	}
 
-	// X680x0 では SCC と呼ぶほうが通りがいい。
-	// イベントの登録は親クラスで行ってある。
-	for (int ch = 0; ch < txevent.size(); ch++) {
-		auto& chan = mpscc.chan[ch];
-		txevent[ch].SetName(string_format("SCC Ch%c TX", chan.name));
-		rxevent[ch].SetName(string_format("SCC Ch%c RX", chan.name));
-	}
-
 	monitor = gMonitorManager->Regist(ID_MONITOR_SCC, this);
 	monitor->func = ToMonitorCallback(&SCCDevice::MonitorUpdate);
 	monitor->SetSize(70, 35);
@@ -87,6 +80,14 @@ SCCDevice::Init()
 		keyboard = GetKeyboard();
 	}
 
+	// X680x0 では SCC と呼ぶほうが通りがいい。
+	// イベントの登録は親クラスで行ってある。
+	for (int ch = 0; ch < txevent.size(); ch++) {
+		auto& chan = mpscc.chan[ch];
+		txevent[ch]->SetName(string_format("SCC Ch%c TX", chan.name));
+		rxevent[ch]->SetName(string_format("SCC Ch%c RX", chan.name));
+	}
+
 	return true;
 }
 
