@@ -11,7 +11,6 @@
 #pragma once
 
 #include "device.h"
-#include "event.h"
 #include "fixedqueue.h"
 #include "mainapp.h"
 #include "scsi.h"
@@ -245,10 +244,10 @@ class SPCDevice : public IODevice
 
 	// Select コマンド実行
 	void SelectCommand();
-	void Arbitration1(Event& ev);
-	void Arbitration2(Event& ev);
-	void Selection1(Event& ev);
-	void SelectionTimeout(Event& ev);
+	void Arbitration1(Event *);
+	void Arbitration2(Event *);
+	void Selection1(Event *);
+	void SelectionTimeout(Event *);
 
 	// SetATN コマンド実行
 	void SetATNCommand();
@@ -257,7 +256,7 @@ class SPCDevice : public IODevice
 
 	// Transfer コマンド実行
 	void TransferCommand();
-	void HardwareTransfer(Event& ev);
+	void HardwareTransfer(Event *);
 	void TransferComplete();
 	// Transfer コマンド実行中なら true
 	bool transfer_command_running {};
@@ -320,8 +319,8 @@ class SPCDevice : public IODevice
 	InterruptDevice *interrupt {};
 
 	// イベント
-	Event phase_event { this };
-	Event timer_event { this };
+	Event *phase_event {};
+	Event *timer_event {};
 
 	// SCSI 管理
 	std::unique_ptr<SCSIDomain> domain /*{}*/;
