@@ -15,6 +15,7 @@
 
 #include "sysclk.h"
 #include "config.h"
+#include "event.h"
 #include "interrupt.h"
 #include "monitor.h"
 #include "scheduler.h"
@@ -26,7 +27,7 @@ SysClkDevice::SysClkDevice()
 {
 	monitor = gMonitorManager->Regist(ID_MONITOR_SYSCLK, this);
 	monitor->func = ToMonitorCallback(&SysClkDevice::MonitorUpdate);
-	monitor->SetSize(31, 3);
+	monitor->SetSize(32, 4);
 }
 
 // デストラクタ
@@ -44,16 +45,16 @@ SysClkDevice::Init()
 	const ConfigItem& item = gConfig->Find("!sysclk-freq");
 	freq = item.AsInt();
 	period = 1_sec / freq;
-	event.time = period;
 
 	// クロックの同期方法
-	auto syncer = GetSyncer();
+	syncer = GetSyncer();
 	sync_rt = syncer->GetSyncRealtime();
 
-	event.func = ToEventCallback(&SysClkDevice::Callback);
-	event.code = 0;
-	event.SetName("System Clock");
-	scheduler->RegistEvent(event);
+	auto evman = GetEventManager();
+	event = evman->Regist(this,
+		ToEventCallback(&SysClkDevice::Callback),
+		"System Clock");
+	event->time = period;
 
 	return true;
 }
@@ -120,9 +121,25 @@ SysClkDevice::MonitorUpdate(Monitor *, TextScreen& screen)
 
 	int width = stime < 86400_sec ? 20 : 25;
 	screen.Print(0, y++, "Freq: %u Hz", freq);
-	screen.Print(0, y++, "Sync: %s", sync_rt ? "Real Time" : "Virtual Time");
-	screen.Print(0, y++, (sync_rt ? TA::Normal : TA::Disable),
-		"Time: %*s", width, TimeToStr(stime).c_str());
+	if (sync_rt) {
+		screen.Puts(0,  y++, "Sync: Real Time");
+		screen.Print(0, y++, "Time:  %*s", width, TimeToStr(stime).c_str());
+
+		// TimeToStr は負は想定していないし、符号は数値の直前に足したい。
+		screen.Puts(0, y, "Diff:");
+		bool neg = false;
+		if (delta < 0) {
+			delta = -delta;
+			neg = true;
+		}
+		std::string s = TimeToStr(delta);
+		int offset = width - s.size();
+		screen.Print(6 + offset, y++, "%c%s", (neg ? '-' : '+'), s.c_str());
+	} else {
+		screen.Puts(0, y++, "Sync: Virtual Time");
+		screen.Puts(0, y++, TA::Disable, "Time:");
+		screen.Puts(0, y++, TA::Disable, "Diff:");
+	}
 }
 
 // 割り込み状態を取得(?)
@@ -139,7 +156,7 @@ SysClkDevice::GetInt() const
 
 // イベントハンドラ
 void
-SysClkDevice::Callback(Event& ev)
+SysClkDevice::Callback(Event *ev)
 {
 	putlog(3, "Interrupt occured");
 
@@ -151,6 +168,10 @@ SysClkDevice::Callback(Event& ev)
 		// 足す前は前回の割り込み発生時刻なので period を足すと現在時刻。
 		stime += period;
 
+		// ホスト時間とここで作った実時間との差。
+		uint64 now = syncer->GetRealTime();
+		delta = (int64)(now - stime);
+
 		scheduler->StartRealtimeEvent(ev, stime, period);
 	} else {
 		scheduler->StartEvent(ev);
