@@ -11,7 +11,6 @@
 #pragma once
 
 #include "virtio_base.h"
-#include "event.h"
 #include "hostnet.h"
 #include "message.h"
 
@@ -38,7 +37,7 @@ class VirtIONetDevice : public VirtIODevice, public IHWAddrFilter
 	// 受信
 	void HostRxCallback(uint32);
 	void RxMessage(MessageID, uint32);
-	void RxEvent(Event&);
+	void RxEvent(Event *);
 	void Rx(VirtQueue *);
 
 	MacAddr macaddr {};
@@ -48,5 +47,5 @@ class VirtIONetDevice : public VirtIODevice, public IHWAddrFilter
 
 	std::unique_ptr<HostNetDevice> hostnet /*{}*/;
 
-	Event event { this };
+	Event *event {};
 };
