@@ -26,7 +26,7 @@ VM_NEWS::VM_NEWS()
 	// 実時間に同期したほうが便利。
 	gConfig->SetDefault("clock-sync", "real");
 	// 仮想コンソール。
-	gConfig->SetDefault("hostcom-driver", "cons");
+	gConfig->SetDefault("hostcom0-driver", "console");
 	// MPU 種別。
 	gConfig->SetDefault("mpu-type", "68030");
 	// MPU クロックの初期値は機種ごとに異なる。単位は MHz
