@@ -22,6 +22,7 @@
 // SHIFT キーについては keyboard.cpp のコメントを参照。
 
 #include "x68kkbd.h"
+#include "event.h"
 #include "mfp.h"
 #include "monitor.h"
 #include "scc.h"
@@ -56,14 +57,14 @@ X68030Keyboard::Init()
 	scc = GetSCCDevice();
 	sysport = GetSysportDevice();
 
-	rept_event.func = ToEventCallback(&X68030Keyboard::ReptCallback);
-	rept_event.time = 0;
-	rept_event.SetName("Keyboard Repeat");
-	scheduler->RegistEvent(rept_event);
+	auto evman = GetEventManager();
+	rept_event = evman->Regist(this,
+		ToEventCallback(&X68030Keyboard::ReptCallback),
+		"Keyboard Repeat");
 
-	mouse_event.func = ToEventCallback(&X68030Keyboard::MouseCallback);
-	mouse_event.SetName("Mouse");
-	scheduler->RegistEvent(mouse_event);
+	mouse_event = evman->Regist(this,
+		ToEventCallback(&X68030Keyboard::MouseCallback),
+		"Mouse");
 
 	return true;
 }
@@ -83,7 +84,7 @@ X68030Keyboard::MDConnect()
 
 	// XXX マウスの接続取り外しは未定
 	scheduler->StopEvent(mouse_event);
-	mouse_event.code = 0;
+	mouse_event->code = 0;
 }
 
 // キーボード取り外し時の MD 固有処理
@@ -92,7 +93,7 @@ X68030Keyboard::MDDisconnect()
 {
 	scheduler->StopEvent(rept_event);
 	scheduler->StopEvent(mouse_event);
-	mouse_event.code = 0;
+	mouse_event->code = 0;
 }
 
 // モニター
@@ -223,7 +224,7 @@ X68030Keyboard::KeyInput(uint keystat)
 	if (ismake) {
 		// いま起きているリピートは中止
 		rept_key = keycode;
-		rept_event.time = rept_delay;
+		rept_event->time = rept_delay;
 		scheduler->RestartEvent(rept_event);
 	} else {
 		if (keycode == rept_key) {
@@ -235,14 +236,14 @@ X68030Keyboard::KeyInput(uint keystat)
 }
 
 void
-X68030Keyboard::ReptCallback(Event& ev)
+X68030Keyboard::ReptCallback(Event *ev)
 {
 	// リピート
 	sendqueue.Enqueue(KeyToMDKey(rept_key));
 	SendStart();
 
 	// 二回目以降のリピートは rept_time 間隔で発生
-	rept_event.time = rept_time;
+	rept_event->time = rept_time;
 	scheduler->StartEvent(rept_event);
 }
 
@@ -330,8 +331,8 @@ X68030Keyboard::MouseSendStart()
 	uint8 status = 0;
 
 	// 最後のバイトを送るまでは、次は受け付けられない。
-	// 送信中かどうかは mouse_event.code で判断している。
-	if (mouse_event.code != 0) {
+	// 送信中かどうかは mouse_event->code で判断している。
+	if (mouse_event->code != 0) {
 		return;
 	}
 
@@ -364,14 +365,14 @@ X68030Keyboard::MouseSendStart()
 
 	// 1バイト目は MSCTRL が立ち下がってから 700us 以上後から送信。
 	// さらに1バイトの送信に 2.3msec かかる(このすぐ下参照)。
-	mouse_event.time = 700_usec + 2300_usec;
-	mouse_event.code = 1;
+	mouse_event->time = 700_usec + 2300_usec;
+	mouse_event->code = 1;
 	scheduler->RestartEvent(mouse_event);
 }
 
 // マウスデータのイベントコールバック
 void
-X68030Keyboard::MouseCallback(Event& ev)
+X68030Keyboard::MouseCallback(Event *ev)
 {
 	// マウスは 4800bps で、ストップビット 2 なので11ビット。
 	// 1/4800 * 11 = 2.29166 msec なので、1バイトあたり 2.3 msec にしておく。
@@ -381,16 +382,16 @@ X68030Keyboard::MouseCallback(Event& ev)
 	// code 3 なら3バイト目 (mouse_data[2]) の送信完了時刻が来た。
 	// 3バイト目を送信してイベントループ終了。
 
-	scc->Rx(1, mouse_data[mouse_event.code - 1]);
+	scc->Rx(1, mouse_data[mouse_event->code - 1]);
 
-	if (mouse_event.code < 3) {
+	if (mouse_event->code < 3) {
 		// 次のイベント
-		mouse_event.time = 2300_usec;
-		mouse_event.code++;
+		mouse_event->time = 2300_usec;
+		mouse_event->code++;
 		scheduler->StartEvent(mouse_event);
 	} else {
 		// 3 バイト目の送信が終わった。
-		mouse_event.code = 0;
+		mouse_event->code = 0;
 	}
 }
 
@@ -422,7 +423,7 @@ X68030Keyboard::Command(uint32 data)
 		// 0 が明るく 3 が暗いので、明るさというより暗さ。
 		led_darkness = (data & 3);
 		putlog(1, "Command LED brightness %u", led_darkness);
-		UIMessage::Post(UIMessage::KEYBOARD);
+		uimessage->Post(UIMessage::KEYBOARD);
 
 	} else if (data < 0x5c) {
 		// $58-$5b 本体からのディスプレイ制御許可
@@ -458,7 +459,7 @@ X68030Keyboard::Command(uint32 data)
 			led[i] = ((data & b) == 0);
 			b <<= 1;
 		}
-		UIMessage::Post(UIMessage::KEYBOARD);
+		uimessage->Post(UIMessage::KEYBOARD);
 	}
 }
 
