@@ -41,6 +41,8 @@ class WXApp : public wxApp
 	std::unique_ptr<HostInfoMonitor> pHostInfo {};
 };
 
+static std::string utf8_to_sjis(const std::string&);
+
 // IMPLEMENT_APP() は闇マクロすぎて clang のちからには耐えられない
 PRAGMA_PUSH_WARNINGS
 IMPLEMENT_APP(WXApp)
@@ -63,7 +65,7 @@ WXApp::OnRun()
 {
 	int rv;
 
-	rv = gMainApp.Init1(false, argc, argv);
+	rv = gMainApp.Init1(argc, argv, utf8_to_sjis);
 	if (rv != MainApp::PASS) {
 		return rv;
 	}
@@ -449,3 +451,21 @@ WXApp::FindAvailable(const std::vector<uint>& candidates,
 	// 候補が他にもあった
 	return 0;
 }
+
+// UTF-8 文字列を Shift_JIS 文字列に変換して返すグローバル関数。
+// GUI の場合に host/logger.cpp で必要なのだが、このために iconv を
+// 追加で要求するのはビルド的に手間なので、wxWidgets の機構を使う。
+// Shift_JIS への変換が発生するのは GUI 起動の場合だけなので問題ない。
+static std::string
+utf8_to_sjis(const std::string& utf8str)
+{
+	static wxCSConv conv("CP932");
+
+	// UTF-8 -> wxString
+	wxString wstr(utf8str.c_str(), wxConvUTF8);
+
+	// wxString -> Shift_JIS
+	wxCharBuffer sjisbuf = wstr.mb_str(conv);
+
+	return std::string(sjisbuf.data());
+}
