@@ -33,9 +33,7 @@ WXLogSettingPanel::WXLogSettingPanel(wxWindow *parent)
 
 	// エイリアスを持つオブジェクトだけ抜き出す
 	for (const auto obj : gMainApp.GetObjects()) {
-		if (obj->GetAliases().empty() == false &&
-			obj->GetId() != OBJ_LOGMONITOR)
-		{
+		if (obj->GetAliases().empty() == false) {
 			objs.emplace_back(obj);
 		}
 	}
