@@ -30,7 +30,7 @@ class WXMainFrame : public wxFrame
 	using inherited = wxFrame;
  public:
 	explicit WXMainFrame(wxWindow *);
-	virtual ~WXMainFrame() override;
+	~WXMainFrame() override;
 
 	// (設定反映などの) 初期化
 	bool Init();
