@@ -12,7 +12,7 @@
 #include "wxmainframe.h"
 #include "wxuimessage.h"
 #include "config.h"
-#include "event.h"
+#include "device.h"
 #include "keyboard.h"
 #include "renderer.h"
 #include <wx/event.h>
