@@ -32,11 +32,15 @@ enum {
 	IDGROUP_MEMDUMP,
 	IDGROUP_MEMDUMP_END = IDGROUP_MEMDUMP + 9,
 
+	// wxgvrammonitor
+	IDGROUP_GVRAM,
+	IDGROUP_GVRAM_END = IDGROUP_GVRAM + 9,
+
 	// wxlogsetting
 	IDGROUP_LOGSETTING,
 	IDGROUP_LOGSETTING_END = IDGROUP_LOGSETTING + 199,
 
-	// wxplanemonitor
-	IDGROUP_PLANEVRAM,
-	IDGROUP_PLANEVRAM_END = IDGROUP_PLANEVRAM + 9,
+	// wxtvrammonitor
+	IDGROUP_TVRAM,
+	IDGROUP_TVRAM_END = IDGROUP_TVRAM + 9,
 };
