@@ -52,6 +52,8 @@ class WXTextScreen : public WXTextPanel
 	int GetPaddingTop() const    { return pad_top; }
 	int GetPaddingRight() const  { return pad_right; }
 	int GetPaddingBottom() const { return pad_bottom; }
+	int GetPaddingX() const	{ return GetPaddingLeft() + GetPaddingRight(); }
+	int GetPaddingY() const { return GetPaddingTop() + GetPaddingBottom(); }
 
 	// 桁数、行数を取得する
 	int GetCol() const { return screen.GetCol(); }
@@ -95,5 +97,8 @@ class WXTextScreen : public WXTextPanel
 	int pad_right {};
 	int pad_bottom {};
 
+	// 余白を塗りつぶす場合は true
+	bool draw_padding {};
+
 	wxDECLARE_EVENT_TABLE();
 };
